==> apache-baremaps-0.7.3-incubating-src.tar.gz: apache-baremaps-0.7.3-incubating-src/baremaps-core/src/main/java/org/apache/baremaps/iploc/IpLocReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.baremaps.iploc;

import java.io.InputStream;
import java.util.Optional;
import java.util.stream.Stream;
import org.apache.lucene.search.SearcherManager;

/** A reader for IP location data. */
public class IpLocReader {

  private final SearcherManager searcherManager;

  /**
   * Constructs an {@code IpLocReader} with the specified {@code SearcherManager} used to lookup
   * locations.
   *
   * @param searcherManager the {@code SearcherManager}
   */
  public IpLocReader(SearcherManager searcherManager) {
    this.searcherManager = searcherManager;
  }

  /**
   * Creates an ordered stream of IP location objects.
   *
   * @param inputStream a {@link InputStream} containing IP location objects
   * @return a {@link Stream} of IP location objects
   */
  public Stream<IpLocObject> read(InputStream inputStream) {
    var nicReader = new NicReader();
    return nicReader.read(inputStream)
        .map(new IpLocMapper(searcherManager))
        .filter(Optional::isPresent)
        .map(Optional::get);
  }
}

==> apache-baremaps-0.8.1-incubating-src.tar.gz: apache-baremaps-0.8.1-incubating-src/baremaps-core/src/main/java/org/apache/baremaps/iploc/IpLocReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.baremaps.iploc;

import java.io.InputStream;
import java.util.Optional;
import java.util.stream.Stream;
import org.apache.baremaps.rpsl.RpslReader;
import org.apache.lucene.search.SearcherManager;

/** A reader for IP location data. */
public class IpLocReader {

  private final SearcherManager searcherManager;

  /**
   * Constructs an {@code IpLocReader} with the specified {@code SearcherManager} used to lookup
   * locations.
   *
   * @param searcherManager the {@code SearcherManager}
   */
  public IpLocReader(SearcherManager searcherManager) {
    this.searcherManager = searcherManager;
  }

  /**
   * Creates an ordered stream of IP location objects.
   *
   * @param inputStream a {@link InputStream} containing IP location objects
   * @return a {@link Stream} of IP location objects
   */
  public Stream<IpLocObject> read(InputStream inputStream) {
    var rpslReader = new RpslReader();
    return rpslReader.read(inputStream)
        .map(new IpLocMapper(searcherManager))
        .filter(Optional::isPresent)
        .map(Optional::get);
  }
}
